==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/FocusOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FocusOptionsDescription } from "./FocusOptionsDescription";
/**
 * @hidden
 */
var FocusOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FocusOptionsDescriptionMetadata, _super);
    function FocusOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FocusOptionsDescriptionMetadata.b = function (a) {
        if (FocusOptionsDescriptionMetadata.a == null) {
            FocusOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FocusOptionsDescriptionMetadata.c(FocusOptionsDescriptionMetadata.a);
        }
        if (a.j(FocusOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(FocusOptionsDescriptionMetadata.a);
    };
    FocusOptionsDescriptionMetadata.c = function (a) {
        a.item("PreventScroll", "Boolean");
    };
    FocusOptionsDescriptionMetadata.d = function (a) {
        FocusOptionsDescriptionMetadata.b(a);
        a.aa("FocusOptions", function () { return new FocusOptionsDescription(); });
        a.z("FocusOptions", FocusOptionsDescriptionMetadata.a);
    };
    FocusOptionsDescriptionMetadata.$t = markType(FocusOptionsDescriptionMetadata, 'FocusOptionsDescriptionMetadata');
    FocusOptionsDescriptionMetadata.a = null;
    return FocusOptionsDescriptionMetadata;
}(Base));
export { FocusOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FocusOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FocusOptionsDescription } from "./FocusOptionsDescription";
/**
 * @hidden
 */
var FocusOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FocusOptionsDescriptionMetadata, _super);
    function FocusOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FocusOptionsDescriptionMetadata.b = function (a) {
        if (FocusOptionsDescriptionMetadata.a == null) {
            FocusOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FocusOptionsDescriptionMetadata.c(FocusOptionsDescriptionMetadata.a);
        }
        if (a.k(FocusOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(FocusOptionsDescriptionMetadata.a);
    };
    FocusOptionsDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("PreventScroll", "Boolean");
    };
    FocusOptionsDescriptionMetadata.d = function (a) {
        FocusOptionsDescriptionMetadata.b(a);
        a.ac("FocusOptions", function () { return new FocusOptionsDescription(); });
        a.ab("FocusOptions", FocusOptionsDescriptionMetadata.a);
    };
    FocusOptionsDescriptionMetadata.$t = markType(FocusOptionsDescriptionMetadata, 'FocusOptionsDescriptionMetadata');
    FocusOptionsDescriptionMetadata.a = null;
    return FocusOptionsDescriptionMetadata;
}(Base));
export { FocusOptionsDescriptionMetadata };
